@@ -1,8 +1,7 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- *
+/*
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2003 - Paolo Maggi <paolo.maggi@polito.it>
+ * Copyright 2003 - Paolo Maggi <paolo.maggi@polito.it>
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,8 +17,7 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GTK_SOURCE_STYLE_PRIVATE_H
-#define GTK_SOURCE_STYLE_PRIVATE_H
+#pragma once
 
 #include <gtk/gtk.h>
 
@@ -34,15 +32,15 @@ G_BEGIN_DECLS
 
 enum
 {
-	GTK_SOURCE_STYLE_USE_LINE_BACKGROUND = 1 << 0,	/*< nick=use_line_background >*/
-	GTK_SOURCE_STYLE_USE_BACKGROUND      = 1 << 1,	/*< nick=use_background >*/
-	GTK_SOURCE_STYLE_USE_FOREGROUND      = 1 << 2,	/*< nick=use_foreground >*/
-	GTK_SOURCE_STYLE_USE_ITALIC          = 1 << 3,	/*< nick=use_italic >*/
-	GTK_SOURCE_STYLE_USE_BOLD            = 1 << 4,	/*< nick=use_bold >*/
-	GTK_SOURCE_STYLE_USE_UNDERLINE       = 1 << 5,	/*< nick=use_underline >*/
-	GTK_SOURCE_STYLE_USE_STRIKETHROUGH   = 1 << 6,	/*< nick=use_strikethrough >*/
-	GTK_SOURCE_STYLE_USE_SCALE           = 1 << 7,	/*< nick=use_scale >*/
-	GTK_SOURCE_STYLE_USE_UNDERLINE_COLOR = 1 << 8	/*< nick=use_underline_color >*/
+	GTK_SOURCE_STYLE_USE_LINE_BACKGROUND = 1 << 0, /*< nick=use_line_background >*/
+	GTK_SOURCE_STYLE_USE_BACKGROUND      = 1 << 1, /*< nick=use_background >*/
+	GTK_SOURCE_STYLE_USE_FOREGROUND      = 1 << 2, /*< nick=use_foreground >*/
+	GTK_SOURCE_STYLE_USE_ITALIC          = 1 << 3, /*< nick=use_italic >*/
+	GTK_SOURCE_STYLE_USE_BOLD            = 1 << 4, /*< nick=use_bold >*/
+	GTK_SOURCE_STYLE_USE_UNDERLINE       = 1 << 5, /*< nick=use_underline >*/
+	GTK_SOURCE_STYLE_USE_STRIKETHROUGH   = 1 << 6, /*< nick=use_strikethrough >*/
+	GTK_SOURCE_STYLE_USE_SCALE           = 1 << 7, /*< nick=use_scale >*/
+	GTK_SOURCE_STYLE_USE_UNDERLINE_COLOR = 1 << 8, /*< nick=use_underline_color >*/
 };
 
 struct _GtkSourceStyle
@@ -67,5 +65,3 @@ struct _GtkSourceStyle
 };
 
 G_END_DECLS
-
-#endif  /* GTK_SOURCE_STYLE_PRIVATE_H */
